@@ -278,7 +278,9 @@ var ConfigDefault = {
     "prisma_read_func_name": str("prisma_read_func_name", "read"),
     "prisma_database_url_name": str("prisma_database_url_name", "DATABASE_URL"),
 
-    "metering_tagcount_enabled": bool("metering_tagcount_enabled", false)
+    "metering_tagcount_enabled": bool("metering_tagcount_enabled", false),
+
+    "trace_cron_enabled": bool("trace_cron_enabled", true)
 };
 
 ConfigDefault._hook_method_ignore_prefix = ConfigDefault.hook_method_ignore_prefixes.split(',');
