@@ -191,15 +191,15 @@ PackageCtrHelper.hookMethod = function(obj, modulePath, methodName, className) {
                 return originalMethod.apply(this, arguments);
             }
 
-            var startTime = Date.now();
+            var startTime = ctx.start_time = Date.now();
             var error = null;
             var result = null;
 
             // Capture original arguments once for later use
             var originalArgs = arguments;
 
-            // Format: "ClassName.methodName" if className exists, otherwise "modulePath/methodName"
-            var methodFullPath = className ? className + '.' + methodName : modulePath + '/' + methodName;
+            // Format: "ClassName.methodName" if className exists, otherwise "NULL.methodName"
+            var methodFullPath = className ? className + '.' + methodName : 'NULL.' + methodName;
 
             // Convert arguments to string once
             var argsString = '';
