@@ -35,7 +35,8 @@ var Interceptor      = require('./interceptor').Interceptor,
     ApolloObserver   = require('../observers/apollo-server-observer').ApolloServerObserver,
     PrismaObserver  = require('../observers/prisma-observer').PrismaObserver,
     OracleObserver  = require('../observers/oracle-observer').OracleObserver,
-    CustomMethodObserver = require('../observers/custom-method-observer').CustomMethodObserver;
+    CustomMethodObserver = require('../observers/custom-method-observer').CustomMethodObserver,
+    CronObserver = require('../observers/cron-observer').CronObserver;
 
 
 var Configuration    = require('./../conf/configure'),
@@ -965,12 +966,19 @@ NodeAgent.prototype.startGoAgent = function(opts = {}) {
     if (pid) {
         try {
             if (this.isGoAgentRunning(pid)) {
-                Logger.print("WHATAP-106", `Found existing agent with PID ${pid}, terminating...`, false);
-                try {
-                    process.kill(parseInt(pid), 'SIGKILL');
-                    Logger.print("WHATAP-107", `Successfully terminated existing agent with PID ${pid}`, false);
-                } catch (killError) {
-                    Logger.printError("WHATAP-108", `Error terminating process with PID ${pid}`, killError, false);
+                // Windows: 기존 프로세스가 실행 중이면 스킵 (Python agent와 동일한 동작)
+                // Unix/Linux: 기존 프로세스 종료 후 새로 시작
+                if (process.platform === 'win32') {
+                    Logger.print("WHATAP-106", `Agent already running (PID: ${pid}). Skipping duplicate execution.`, false);
+                    return;
+                } else {
+                    Logger.print("WHATAP-106", `Found existing agent with PID ${pid}, terminating...`, false);
+                    try {
+                        process.kill(parseInt(pid), 'SIGKILL');
+                        Logger.print("WHATAP-107", `Successfully terminated existing agent with PID ${pid}`, false);
+                    } catch (killError) {
+                        Logger.printError("WHATAP-108", `Error terminating process with PID ${pid}`, killError, false);
+                    }
                 }
             }
         } catch (e) {
@@ -983,10 +991,16 @@ NodeAgent.prototype.startGoAgent = function(opts = {}) {
 
     try {
         // 바이너리 경로 설정
-        const agentPath = path.join(whatapHome, AGENT_NAME);
         const platform = process.platform;
         const architecture = ARCH[process.arch] || process.arch;
-        const sourcePath = path.join(__dirname, '..', '..', 'agent', platform, architecture, AGENT_NAME);
+
+        const binaryName = platform === 'win32' ? AGENT_NAME + '.exe' : AGENT_NAME;
+        const agentPath = path.join(whatapHome, binaryName);
+
+        // Windows는 architecture 하위 디렉토리 없이 단일 바이너리 사용
+        const sourcePath = platform === 'win32'
+            ? path.join(__dirname, '..', '..', 'agent', 'windows', binaryName)
+            : path.join(__dirname, '..', '..', 'agent', platform, architecture, AGENT_NAME);
 
         // sourcePath 존재 여부 확인
         if (!fs.existsSync(sourcePath)) {
@@ -1004,8 +1018,10 @@ NodeAgent.prototype.startGoAgent = function(opts = {}) {
                     Logger.print("WHATAP-037", `Symlink failed (${e.code}), copying binary instead`, false);
                     try {
                         fs.copyFileSync(sourcePath, agentPath);
-                        // 실행 권한 부여
-                        fs.chmodSync(agentPath, 0o755);
+                        // 실행 권한 부여 (Windows는 불필요)
+                        if (platform !== 'win32') {
+                            fs.chmodSync(agentPath, 0o755);
+                        }
                         Logger.print("WHATAP-221", `Binary copied and made executable at ${agentPath}`, false);
                     } catch (copyErr) {
                         throw new Error(`Failed to copy agent binary: ${copyErr.message}`);
@@ -1014,12 +1030,14 @@ NodeAgent.prototype.startGoAgent = function(opts = {}) {
             }
         }
 
-        // agentPath 실행 권한 확인
-        try {
-            fs.accessSync(agentPath, fs.constants.X_OK);
-        } catch (e) {
-            Logger.print("WHATAP-222", `Agent binary not executable, adding execute permission`, false);
-            fs.chmodSync(agentPath, 0o755);
+        // agentPath 실행 권한 확인 (Windows는 스킵)
+        if (platform !== 'win32') {
+            try {
+                fs.accessSync(agentPath, fs.constants.X_OK);
+            } catch (e) {
+                Logger.print("WHATAP-222", `Agent binary not executable, adding execute permission`, false);
+                fs.chmodSync(agentPath, 0o755);
+            }
         }
 
         // run 디렉토리 생성
@@ -1068,16 +1086,27 @@ NodeAgent.prototype.startGoAgent = function(opts = {}) {
         Object.assign(newEnv, opts);
 
         // 에이전트 프로세스 시작
-        const agentProcess = child_process.spawn(
-            agentPath,
-            ['-t', '2', '-d', '1'],
-            {
-                cwd: whatapHome,
-                env: newEnv,
-                stdio: ['pipe', 'pipe', 'pipe'],
-                detached: false
-            }
-        );
+        // Windows: -t 2 foreground (detached 모드)
+        // Unix/Linux: -t 2 -d 1 (daemon 모드)
+        const spawnArgs = platform === 'win32'
+            ? ['-t', '2', 'foreground']
+            : ['-t', '2', '-d', '1'];
+
+        const spawnOptions = {
+            cwd: whatapHome,
+            env: newEnv,
+            stdio: ['pipe', 'pipe', 'pipe'],
+            detached: platform === 'win32' // Windows에서는 detached 모드
+        };
+
+        // Windows에서는 DETACHED_PROCESS 플래그 추가
+        if (platform === 'win32') {
+            spawnOptions.detached = true;
+            // Windows 전용: 새로운 콘솔 윈도우 생성 방지
+            spawnOptions.windowsHide = true;
+        }
+
+        const agentProcess = child_process.spawn(agentPath, spawnArgs, spawnOptions);
 
         const MAX_BUFFER_SIZE = 50000; // 50KB - prevent memory leak
         let stdout = '';
@@ -1322,6 +1351,7 @@ NodeAgent.prototype.loadObserves = function() {
     observes.push(ApolloObserver);
     observes.push(PrismaObserver);
     observes.push(OracleObserver);
+    observes.push(CronObserver);
 
     var packageToObserve = {};
     observes.forEach(function(observeObj) {
