@@ -128,6 +128,11 @@ HttpObserver.prototype.__createTransactionObserver = function (callback, isHttps
             }
 
             ctx.service_name = req.url ? req.url : "";
+            ctx.isStaticContents = isStatic(ctx.service_name);
+            if(ctx.isStaticContents){
+                return callback(req, res);
+            }
+
             let hostname = ctx.host && ctx.host.includes(':') ? ctx.host.split(':')[0] : '';
             let datas = [
                 hostname,
@@ -247,17 +252,6 @@ function initCtx(req, res) {
     // Host
     ctx.host = req.headers.host;
 
-    /************************************/
-    /*   Header / param Trace           */
-    /************************************/
-    var header_enabled = false;
-    if(conf.profile_http_header_enabled === true && req.headers) {
-        header_enabled = true;
-        var prefix = conf.profile_header_url_prefix;
-        if(prefix && ctx.service_name.indexOf(prefix) < 0) {
-            header_enabled = false;
-        }
-    }
     /************************************/
     /*   Header / param Trace           */
     /************************************/
