@@ -11,6 +11,9 @@ var Long    = require('long'),
 
 var KeyGen = {
     next : function () {
+        return parseInt((Long.fromBits(rand.int32(), rand.int32())).toString());
+    },
+    getMtid : function () {
         return Long.fromBits(rand.int32(), rand.int32());
     }
 };
